@@ -1,4 +1,4 @@
-import datetime
+import json
 import time
 from abc import abstractmethod, ABC
 from typing import List, Optional
@@ -24,6 +24,9 @@ class _Module(ABC):
         """
         return {'type': self.type}
 
+    def build_to_json(self) -> str:
+        return json.dumps(self.build(), indent=4, ensure_ascii=False)
+
 
 class Header(_Module):
     """
